@@ -1,6 +1,8 @@
 # --
 # Kernel/GenericInterface/Operation/Ticket/Common.pm - Ticket common operation functions
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: Common.pm,v 1.35.2.1 2012-05-29 17:32:31 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -36,7 +38,8 @@ use Kernel::System::DynamicField::Backend;
 use Kernel::System::GenericInterface::Webservice;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.35.2.1 $) [1];
 
 =head1 NAME
 
@@ -811,7 +814,7 @@ sub ValidatePendingTime {
     return if !IsHashRefWithData( $Param{PendingTime} );
 
     # check that no time attibute is empty or negative
-    for my $TimeAttribute ( sort keys %{ $Param{PendingTime} } ) {
+    for my $TimeAttribute ( keys %{ $Param{PendingTime} } ) {
         return if $Param{PendingTime}->{$TimeAttribute} eq '';
         return if int $Param{PendingTime}->{$TimeAttribute} < 0,
     }
@@ -1525,3 +1528,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.35.2.1 $ $Date: 2012-05-29 17:32:31 $
+
+=cut
