@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AdminGenericInterfaceTransportHTTPSOAP.pm - provides a TransportHTTPSOAP view for admins
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: AdminGenericInterfaceTransportHTTPSOAP.pm,v 1.10 2012-03-15 02:15:26 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,10 +14,14 @@ package Kernel::Modules::AdminGenericInterfaceTransportHTTPSOAP;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.10 $) [1];
+
 use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::GenericInterface::Webservice;
 use Kernel::System::Valid;
 use Kernel::System::JSON;
+use YAML;
 
 use Kernel::System::VariableCheck qw(:all);
 
@@ -31,7 +37,7 @@ sub new {
         }
     }
 
-    # create additional objects
+    # create addtional objects
     $Self->{ValidObject} = Kernel::System::Valid->new( %{$Self} );
     $Self->{JSONObject}  = Kernel::System::JSON->new( %{$Self} );
     $Self->{WebserviceObject} =
@@ -55,12 +61,11 @@ sub Run {
 
         # check for WebserviceID
         if ( !$WebserviceID ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => "Need WebserviceID!",
-            );
+            return $Self->{LayoutObject}
+                ->ErrorScreen( Message => "Need WebserviceID!", );
         }
 
-        # get webservice configuration
+        # get webserice configuration
         my $WebserviceData =
             $Self->{WebserviceObject}->WebserviceGet( ID => $WebserviceID );
 
@@ -90,12 +95,11 @@ sub Run {
 
         # check for WebserviceID
         if ( !$WebserviceID ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => "Need WebserviceID!",
-            );
+            return $Self->{LayoutObject}
+                ->ErrorScreen( Message => "Need WebserviceID!", );
         }
 
-        # get webservice configuration
+        # get webserice configuration
         my $WebserviceData =
             $Self->{WebserviceObject}->WebserviceGet( ID => $WebserviceID );
 
@@ -107,7 +111,7 @@ sub Run {
         }
 
         # get parameter from web browser
-        my $GetParam = $Self->_GetParams();
+        my $GetParam = $Self->_GetParams;
 
         # check required parameters
         my %Error;
@@ -212,7 +216,7 @@ sub Run {
             }
         }
 
-        # set new configuration
+        # set new confguration
         $WebserviceData->{Config}->{$CommunicationType}->{Transport}->{Config} = $TransportConfig;
 
         # if there is an error return to edit screen
@@ -251,10 +255,6 @@ sub Run {
             OP => $RedirectURL,
         );
     }
-
-    return $Self->{LayoutObject}->ErrorScreen(
-        Message => "Need Subaction!",
-    );
 }
 
 sub _ShowEdit {
@@ -266,8 +266,8 @@ sub _ShowEdit {
     # configuration
     $Param{Type}           = 'HTTP::SOAP';
     $Param{WebserviceName} = $Param{WebserviceData}->{Name};
-    my $TransportConfig
-        = $Param{WebserviceData}->{Config}->{ $Param{CommunicationType} }->{Transport}->{Config};
+    my $TransportConfig = $Param{WebserviceData}->{Config}->{ $Param{CommunicationType} }
+        ->{Transport}->{Config};
 
     # extract display parameters from transport config
     $Param{Endpoint}            = $TransportConfig->{Endpoint};
