@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketSearch.pm - Utilities for tickets
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketSearch.pm,v 1.118.2.7 2012-08-06 07:34:08 mg Exp $
+# $Id: AgentTicketSearch.pm,v 1.145.2.2 2012-08-06 07:33:37 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -22,9 +22,12 @@ use Kernel::System::SLA;
 use Kernel::System::State;
 use Kernel::System::Type;
 use Kernel::System::CSV;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.118.2.7 $) [1];
+$VERSION = qw($Revision: 1.145.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -51,6 +54,8 @@ sub new {
     $Self->{TypeObject}          = Kernel::System::Type->new(%Param);
     $Self->{CSVObject}           = Kernel::System::CSV->new(%Param);
     $Self->{LockObject}          = Kernel::System::Lock->new(%Param);
+    $Self->{DynamicFieldObject}  = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}       = Kernel::System::DynamicField::Backend->new(%Param);
 
     # if we need to do a fulltext search on an external mirror database
     if ( $Self->{ConfigObject}->Get('Core::MirrorDB::DSN') ) {
@@ -77,6 +82,23 @@ sub new {
 
     $Self->{Config} = $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}");
 
+    # get dynamic field config for frontend module
+    $Self->{DynamicFieldFilter} = $Self->{Config}->{DynamicField};
+
+    # get the dynamic fields for ticket object
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid       => 1,
+        ObjectType  => ['Ticket'],
+        FieldFilter => $Self->{DynamicFieldFilter} || {},
+    );
+
+    # get the ticket dynamic fields for CSV display
+    $Self->{CSVDynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid       => 1,
+        ObjectType  => ['Ticket'],
+        FieldFilter => $Self->{Config}->{SearchCSVDynamicField} || {},
+    );
+
     return $Self;
 }
 
@@ -159,46 +181,6 @@ sub Run {
             Agent ResultForm TimeSearchType ChangeTimeSearchType CloseTimeSearchType UseSubQueues
             ArticleTimeSearchType SearchInArchive
             Fulltext ShownAttributes
-            TicketFreeTime1
-            TicketFreeTime1Start TicketFreeTime1StartDay TicketFreeTime1StartMonth
-            TicketFreeTime1StartYear
-            TicketFreeTime1Stop TicketFreeTime1StopDay TicketFreeTime1StopMonth
-            TicketFreeTime1StopYear
-            TicketFreeTime2
-            TicketFreeTime2Start TicketFreeTime2StartDay TicketFreeTime2StartMonth
-            TicketFreeTime2StartYear
-            TicketFreeTime2Stop TicketFreeTime2StopDay TicketFreeTime2StopMonth
-            TicketFreeTime2StopYear
-            TicketFreeTime3
-            TicketFreeTime3Start TicketFreeTime3StartDay TicketFreeTime3StartMonth
-            TicketFreeTime3StartYear
-            TicketFreeTime3Stop TicketFreeTime3StopDay TicketFreeTime3StopMonth
-            TicketFreeTime3StopYear
-            TicketFreeTime4
-            TicketFreeTime4Start TicketFreeTime4StartDay TicketFreeTime4StartMonth
-            TicketFreeTime4StartYear
-            TicketFreeTime4Stop TicketFreeTime4StopDay TicketFreeTime4StopMonth
-            TicketFreeTime4StopYear
-            TicketFreeTime5
-            TicketFreeTime5Start TicketFreeTime5StartDay TicketFreeTime5StartMonth
-            TicketFreeTime5StartYear
-            TicketFreeTime5Stop TicketFreeTime5StopDay TicketFreeTime5StopMonth
-            TicketFreeTime5StopYear
-            TicketFreeTime6
-            TicketFreeTime6Start TicketFreeTime6StartDay TicketFreeTime6StartMonth
-            TicketFreeTime6StartYear
-            TicketFreeTime6Stop TicketFreeTime6StopDay TicketFreeTime6StopMonth
-            TicketFreeTime6StopYear
-            TicketFreeTime7
-            TicketFreeTime7Start TicketFreeTime7StartDay TicketFreeTime7StartMonth
-            TicketFreeTime7StartYear
-            TicketFreeTime7Stop TicketFreeTime7StopDay TicketFreeTime7StopMonth
-            TicketFreeTime7StopYear
-            TicketFreeTime8
-            TicketFreeTime8Start TicketFreeTime8StartDay TicketFreeTime8StartMonth
-            TicketFreeTime8StartYear
-            TicketFreeTime8Stop TicketFreeTime8StopDay TicketFreeTime8StopMonth
-            TicketFreeTime8StopYear
             ArticleCreateTimePointFormat ArticleCreateTimePoint
             ArticleCreateTimePointStart
             ArticleCreateTimeStart ArticleCreateTimeStartDay ArticleCreateTimeStartMonth
@@ -241,15 +223,7 @@ sub Run {
         for (
             qw(StateIDs StateTypeIDs QueueIDs PriorityIDs OwnerIDs
             CreatedQueueIDs CreatedUserIDs WatchUserIDs ResponsibleIDs
-            TypeIDs ServiceIDs SLAIDs LockIDs
-            TicketFreeKey1 TicketFreeText1 TicketFreeKey2 TicketFreeText2
-            TicketFreeKey3 TicketFreeText3 TicketFreeKey4 TicketFreeText4
-            TicketFreeKey5 TicketFreeText5 TicketFreeKey6 TicketFreeText6
-            TicketFreeKey7 TicketFreeText7 TicketFreeKey8 TicketFreeText8
-            TicketFreeKey9 TicketFreeText9 TicketFreeKey10 TicketFreeText10
-            TicketFreeKey11 TicketFreeText11 TicketFreeKey12 TicketFreeText12
-            TicketFreeKey13 TicketFreeText13 TicketFreeKey14 TicketFreeText14
-            TicketFreeKey15 TicketFreeText15 TicketFreeKey16 TicketFreeText16)
+            TypeIDs ServiceIDs SLAIDs LockIDs)
             )
         {
 
@@ -259,6 +233,26 @@ sub Run {
                 $GetParam{$_} = \@Array;
             }
         }
+
+        # get Dynamic fields form param object
+        # cycle trough the activated Dynamic Fields for this screen
+        DYNAMICFIELD:
+        for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+            # extract the dynamic field value form the web request
+            my $DynamicFieldValue = $Self->{BackendObject}->SearchFieldValueGet(
+                DynamicFieldConfig     => $DynamicFieldConfig,
+                ParamObject            => $Self->{ParamObject},
+                ReturnProfileStructure => 1,
+                LayoutObject           => $Self->{LayoutObject},
+            );
+
+            # set the comple value structure in GetParam to store it later in the search profile
+            if ( IsHashRefWithData($DynamicFieldValue) ) {
+                %GetParam = ( %GetParam, %{$DynamicFieldValue} );
+            }
+        }
     }
 
     # get article create time option
@@ -512,7 +506,7 @@ sub Run {
             }
         }
 
-        # get close time settings
+        # get change time settings
         if ( !$GetParam{ChangeTimeSearchType} ) {
 
             # do nothing on time stuff
@@ -660,46 +654,32 @@ sub Run {
             }
         }
 
-        # free time
-        for ( 1 .. 6 ) {
-            if ( !$GetParam{ 'TicketFreeTime' . $_ } ) {
-                for my $Type (qw(Year Month Day)) {
-                    $GetParam{ 'TicketFreeTime' . $_ . 'Start' . $Type } = undef;
-                    $GetParam{ 'TicketFreeTime' . $_ . 'Stop' . $Type }  = undef;
-                }
-                $GetParam{ 'TicketFreeTime' . $_ . 'NewerDate' } = undef;
-                $GetParam{ 'TicketFreeTime' . $_ . 'OlderDate' } = undef;
-            }
-            else {
-                $GetParam{ 'TicketFreeTime' . $_ } = 'checked="checked"';
-                if (
-                    $GetParam{ 'TicketFreeTime' . $_ . 'StartDay' }
-                    && $GetParam{ 'TicketFreeTime' . $_ . 'StartMonth' }
-                    && $GetParam{ 'TicketFreeTime' . $_ . 'StartYear' }
-                    )
-                {
-                    $GetParam{ 'TicketFreeTime' . $_ . 'NewerDate' }
-                        = $GetParam{ 'TicketFreeTime' . $_ . 'StartYear' } . '-'
-                        . $GetParam{ 'TicketFreeTime' . $_ . 'StartMonth' } . '-'
-                        . $GetParam{ 'TicketFreeTime' . $_ . 'StartDay' }
-                        . ' 00:00:00';
-                }
-                if (
-                    $GetParam{ 'TicketFreeTime' . $_ . 'StopDay' }
-                    && $GetParam{ 'TicketFreeTime' . $_ . 'StopMonth' }
-                    && $GetParam{ 'TicketFreeTime' . $_ . 'StopYear' }
-                    )
-                {
-                    $GetParam{ 'TicketFreeTime' . $_ . 'OlderDate' }
-                        = $GetParam{ 'TicketFreeTime' . $_ . 'StopYear' } . '-'
-                        . $GetParam{ 'TicketFreeTime' . $_ . 'StopMonth' } . '-'
-                        . $GetParam{ 'TicketFreeTime' . $_ . 'StopDay' }
-                        . ' 23:59:59';
-                }
+        # Special behaviour for the fulltext search toolbar module:
+        # - Check full text string to see if contents is a ticket number.
+        # - If exists and not in print or CSV mode, redirect to the ticket.
+        # See http://bugs.otrs.org/show_bug.cgi?id=4238 for details.
+        #   The original problem was that tickets with customer reply will be
+        #   found by a fulltext search (ticket number is in the subjects), but
+        #   'new' tickets will not be found.
+        if (
+            $GetParam{Fulltext}
+            && $Self->{ParamObject}->GetParam( Param => 'CheckTicketNumberAndRedirect' )
+            && $GetParam{ResultForm} ne 'Normal'
+            && $GetParam{ResultForm} ne 'Print'
+            )
+        {
+            my $TicketID = $Self->{TicketObjectSearch}->TicketIDLookup(
+                TicketNumber => $GetParam{Fulltext},
+                UserID       => $Self->{UserID},
+            );
+            if ($TicketID) {
+                return $Self->{LayoutObject}->Redirect(
+                    OP => "Action=AgentTicketZoom;TicketID=$TicketID",
+                );
             }
         }
 
-        # prepare fulltext search
+        # prepare full text search
         if ( $GetParam{Fulltext} ) {
             $GetParam{ContentSearch} = 'OR';
             for (qw(From To Cc Subject Body)) {
@@ -722,6 +702,39 @@ sub Run {
             }
         }
 
+        my %AttributeLookup;
+
+        # create attibute lookup table
+        for my $Attribute ( @{ $GetParam{ShownAttributes} || [] } ) {
+            $AttributeLookup{$Attribute} = 1;
+        }
+
+        # dynamic fields search parameters for ticket search
+        my %DynamicFieldSearchParameters;
+
+        # cycle trough the activated Dynamic Fields for this screen
+        DYNAMICFIELD:
+        for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+            next DYNAMICFIELD
+                if !$AttributeLookup{ 'LabelSearch_DynamicField_' . $DynamicFieldConfig->{Name} };
+
+            # extract the dynamic field value form the profile
+            my $SearchParameter = $Self->{BackendObject}->SearchFieldParameterBuild(
+                DynamicFieldConfig => $DynamicFieldConfig,
+                Profile            => \%GetParam,
+                LayoutObject       => $Self->{LayoutObject},
+            );
+
+            # set search parameter
+            if ( defined $SearchParameter ) {
+                $DynamicFieldSearchParameters{ 'DynamicField_' . $DynamicFieldConfig->{Name} }
+                    = $SearchParameter->{Parameter};
+            }
+
+            # set value to display
+        }
+
         # perform ticket search
         my @ViewableTicketIDs = $Self->{TicketObjectSearch}->TicketSearch(
             Result              => 'ARRAY',
@@ -734,6 +747,7 @@ sub Run {
             ContentSearchSuffix => '*',
             FullTextIndex       => 1,
             %GetParam,
+            %DynamicFieldSearchParameters,
         );
 
         # CSV output
@@ -745,16 +759,22 @@ sub Run {
 
                 # get first article data
                 my %Data = $Self->{TicketObjectSearch}->ArticleFirstArticle(
-                    TicketID => $_,
-                    Extended => 1,
+                    TicketID      => $_,
+                    Extended      => 1,
+                    DynamicFields => 1,
                 );
 
+                for my $Key (qw(State Lock)) {
+                    $Data{$Key} = $Self->{LayoutObject}->{LanguageObject}->Get( $Data{$Key} );
+                }
+
                 $Data{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Data{Age}, Space => ' ' );
 
                 # get whole article (if configured!)
                 if ( $Self->{Config}->{SearchArticleCSVTree} ) {
                     my @Article = $Self->{TicketObjectSearch}->ArticleGet(
-                        TicketID => $_,
+                        TicketID      => $_,
+                        DynamicFields => 0,
                     );
                     for my $Articles (@Article) {
                         if ( $Articles->{Body} ) {
@@ -790,10 +810,52 @@ sub Run {
                 # csv quote
                 if ( !@CSVHead ) {
                     @CSVHead = @{ $Self->{Config}->{SearchCSVData} };
+
+                    # include the selected dynamic fields on CVS resutls
+                    DYNAMICFIELD:
+                    for my $DynamicFieldConfig ( @{ $Self->{CSVDynamicField} } ) {
+                        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+                        next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+                        next DYNAMICFIELD if $DynamicFieldConfig->{Name} eq '';
+
+                        push @CSVHead, 'DynamicField_' . $DynamicFieldConfig->{Name};
+                    }
                 }
                 my @Data;
                 for (@CSVHead) {
-                    push @Data, $Info{$_};
+
+                    # check if header is a dynamic field and get the value from dynamic field
+                    # backend
+                    if ( $_ =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
+
+                        # loop over the dynamic fields configured for CSV output
+                        DYNAMICFIELD:
+                        for my $DynamicFieldConfig ( @{ $Self->{CSVDynamicField} } ) {
+                            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+                            next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+
+                            # skip all fields that does not match with current field name ($1)
+                            # with out the 'DynamicField_' prefix
+                            next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $1;
+
+                            # get the value as for print (to corretly display)
+                            my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+                                DynamicFieldConfig => $DynamicFieldConfig,
+                                Value              => $Info{$_},
+                                HTMLOutput         => 0,
+                                LayoutObject       => $Self->{LayoutObject},
+                            );
+                            push @Data, $ValueStrg->{Value};
+
+                            # terminate the DYNAMICFIELD loop
+                            last DYNAMICFIELD;
+                        }
+                    }
+
+                    # otherwise retreive data from article
+                    else {
+                        push @Data, $Info{$_};
+                    }
                 }
                 push @CSVData, \@Data;
             }
@@ -805,8 +867,18 @@ sub Run {
                 my %UserData = $Self->{UserObject}->GetUserData( UserID => $Self->{UserID} );
                 $UserCSVSeparator = $UserData{UserCSVSeparator};
             }
+
+            my %HeaderMap = (
+                TicketNumber => 'Ticket Number',
+                CustomerName => 'customer realname',
+            );
+
+            my @CSVHeadTranslated
+                = map { $Self->{LayoutObject}->{LanguageObject}->Get( $HeaderMap{$_} || $_ ); }
+                @CSVHead;
+
             my $CSV = $Self->{CSVObject}->Array2CSV(
-                Head      => \@CSVHead,
+                Head      => \@CSVHeadTranslated,
                 Data      => \@CSVData,
                 Separator => $UserCSVSeparator,
             );
@@ -835,7 +907,10 @@ sub Run {
             for (@ViewableTicketIDs) {
 
                 # get first article data
-                my %Data = $Self->{TicketObjectSearch}->ArticleFirstArticle( TicketID => $_ );
+                my %Data = $Self->{TicketObjectSearch}->ArticleFirstArticle(
+                    TicketID      => $_,
+                    DynamicFields => 1,
+                );
 
                 # customer info
                 my %CustomerData;
@@ -1049,6 +1124,7 @@ sub Run {
                     $Param{Warning} = '$Text{"Reached max. count of %s search hits!", "'
                         . $Self->{SearchLimit} . '"}';
                 }
+
                 $Output .= $Self->{LayoutObject}->Output(
                     TemplateFile => 'AgentTicketSearchResultPrint',
                     Data         => \%Param,
@@ -1072,7 +1148,7 @@ sub Run {
             $Self->{Filter} = $Self->{ParamObject}->GetParam( Param => 'Filter' ) || '';
             $Self->{View}   = $Self->{ParamObject}->GetParam( Param => 'View' )   || '';
 
-            # show ticket's
+            # show tickets
             my $LinkPage = 'Filter='
                 . $Self->{LayoutObject}->LinkEncode( $Self->{Filter} )
                 . ';View=' . $Self->{LayoutObject}->LinkEncode( $Self->{View} )
@@ -1168,6 +1244,7 @@ sub Run {
             if ( $Self->{Config}->{Defaults} ) {
                 for my $Key ( sort keys %{ $Self->{Config}->{Defaults} } ) {
                     next if !$Self->{Config}->{Defaults}->{$Key};
+                    next if $Key eq 'DynamicField';
 
                     if ( $Key =~ /^(Ticket|Article)(Create|Change|Close)/ ) {
                         my @Items = split /;/, $Self->{Config}->{Defaults}->{$Key};
@@ -1295,61 +1372,105 @@ sub Run {
             );
         }
 
-        # get free text config options
-        my %TicketFreeText;
-        for ( 1 .. 16 ) {
-            $TicketFreeText{"TicketFreeKey$_"} = $Self->{TicketObject}->TicketFreeTextGet(
-                Type   => "TicketFreeKey$_",
-                FillUp => 1,
-                Action => $Self->{Action},
-                UserID => $Self->{UserID},
-            );
-            $TicketFreeText{"TicketFreeText$_"} = $Self->{TicketObject}->TicketFreeTextGet(
-                Type   => "TicketFreeText$_",
-                FillUp => 1,
-                Action => $Self->{Action},
-                UserID => $Self->{UserID},
-            );
-        }
-        my %TicketFreeTextHTML = $Self->{LayoutObject}->AgentFreeText(
-            NullOption => 1,
-            Ticket     => \%GetParam,
-            Config     => \%TicketFreeText,
-        );
-        for my $Count ( 1 .. 16 ) {
-            next if !$Self->{Config}->{TicketFreeText}->{$Count};
-            my $Config = $Self->{ConfigObject}->Get( 'TicketFreeKey' . $Count );
-            next if !$Config;
-            my $Name = '';
-            for my $Key ( sort keys %{$Config} ) {
-                next if !$Config->{$Key};
-                if ($Name) {
-                    $Name .= '/';
-                }
-                $Name .= $Config->{$Key};
+        my $DynamicFieldSeparator = 1;
+
+        # create dynamic fields seaarch options for attribute select
+        # cycle trough the activated Dynamic Fields for this screen
+        DYNAMICFIELD:
+        for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+            next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+            next DYNAMICFIELD if $DynamicFieldConfig->{Name} eq '';
+
+            # create a separator for dynamic fields attributes
+            if ($DynamicFieldSeparator) {
+                push @Attributes, (
+                    {
+                        Key      => '',
+                        Value    => '-',
+                        Disabled => 1,
+                    },
+                );
+
+                $DynamicFieldSeparator = 0;
             }
-            next if !$Name;
+
             push @Attributes, (
                 {
-                    Key   => 'TicketFreeText' . $Count,
-                    Value => $Name,
+                    Key   => 'Search_DynamicField_' . $DynamicFieldConfig->{Name},
+                    Value => $Self->{LayoutObject}->{LanguageObject}->Get(
+                        $DynamicFieldConfig->{Label}
+                    ),
                 },
             );
         }
 
-        for my $Count ( 1 .. 6 ) {
-            next if !$Self->{Config}->{TicketFreeTime}->{$Count};
-            my $Config = $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count );
-            next if !$Config;
-            my $Name = $Config;
+        # create a separator if a dynamic field attribute was pushed
+        if ( !$DynamicFieldSeparator ) {
             push @Attributes, (
                 {
-                    Key   => 'TicketFreeTime' . $Count,
-                    Value => $Name,
+                    Key      => '',
+                    Value    => '-',
+                    Disabled => 1,
                 },
             );
         }
 
+        # create HTML strings for all dynamic fields
+        my %DynamicFieldHTML;
+
+        # cycle trough the activated Dynamic Fields for this screen
+        DYNAMICFIELD:
+        for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+            my $PossibleValuesFilter;
+
+            # check if field has PossibleValues property in its configuration
+            if ( IsHashRefWithData( $DynamicFieldConfig->{Config}->{PossibleValues} ) ) {
+
+                # get historical values from database
+                my $HistoricalValues = $Self->{BackendObject}->HistoricalValuesGet(
+                    DynamicFieldConfig => $DynamicFieldConfig,
+                );
+
+                my $Data = $DynamicFieldConfig->{Config}->{PossibleValues};
+
+                # add historic values to current values (if they don't exist anymore)
+                if ( IsHashRefWithData($HistoricalValues) ) {
+                    for my $Key ( keys %{$HistoricalValues} ) {
+                        if ( !$Data->{$Key} ) {
+                            $Data->{$Key} = $HistoricalValues->{$Key}
+                        }
+                    }
+                }
+
+                # set possible values filter from ACLs
+                my $ACL = $Self->{TicketObject}->TicketAcl(
+                    Action        => $Self->{Action},
+                    ReturnType    => 'Ticket',
+                    ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
+                    Data          => $Data,
+                    UserID        => $Self->{UserID},
+                );
+                if ($ACL) {
+                    my %Filter = $Self->{TicketObject}->TicketAclData();
+                    $PossibleValuesFilter = \%Filter;
+                }
+            }
+
+            # get field html
+            $DynamicFieldHTML{ $DynamicFieldConfig->{Name} } =
+                $Self->{BackendObject}->SearchFieldRender(
+                DynamicFieldConfig   => $DynamicFieldConfig,
+                Profile              => \%GetParam,
+                PossibleValuesFilter => $PossibleValuesFilter,
+                DefaultValue =>
+                    $Self->{Config}->{Defaults}->{DynamicField}->{ $DynamicFieldConfig->{Name} },
+                LayoutObject => $Self->{LayoutObject},
+                );
+        }
+
         push @Attributes, (
             {
                 Key   => 'LockIDs',
@@ -1781,21 +1902,6 @@ sub Run {
             Format => 'DateInputFormat',
         );
 
-        for ( 1 .. 6 ) {
-            $Param{ 'TicketFreeTime' . $_ . 'Start' } = $Self->{LayoutObject}->BuildDateSelection(
-                %GetParam,
-                Prefix   => 'TicketFreeTime' . $_ . 'Start',
-                Format   => 'DateInputFormat',
-                DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
-            );
-            $Param{ 'TicketFreeTime' . $_ . 'Stop' } = $Self->{LayoutObject}->BuildDateSelection(
-                %GetParam,
-                Prefix   => 'TicketFreeTime' . $_ . 'Stop',
-                Format   => 'DateInputFormat',
-                DiffTime => +( ( 60 * 60 * 24 ) * 30 ),
-            );
-        }
-
         $Param{TicketChangeTimePoint} = $Self->{LayoutObject}->BuildSelection(
             Data => {
                 1  => ' 1',
@@ -1997,21 +2103,6 @@ sub Run {
             }
         }
 
-        for ( 1 .. 6 ) {
-            $Param{ 'TicketFreeTime' . $_ . 'Start' } = $Self->{LayoutObject}->BuildDateSelection(
-                %GetParam,
-                Prefix   => 'TicketFreeTime' . $_ . 'Start',
-                Format   => 'DateInputFormat',
-                DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
-            );
-            $Param{ 'TicketFreeTime' . $_ . 'Stop' } = $Self->{LayoutObject}->BuildDateSelection(
-                %GetParam,
-                Prefix   => 'TicketFreeTime' . $_ . 'Stop',
-                Format   => 'DateInputFormat',
-                DiffTime => +( ( 60 * 60 * 24 ) * 30 ),
-            );
-        }
-
         # build type string
         if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
             my %Type = $Self->{TypeObject}->TypeList( UserID => $Self->{UserID}, );
@@ -2029,9 +2120,33 @@ sub Run {
         # html search mask output
         $Self->{LayoutObject}->Block(
             Name => 'SearchAJAX',
-            Data => { %Param, %GetParam, %TicketFreeTextHTML, EmptySearch => $EmptySearch },
+            Data => {
+                %Param,
+                %GetParam,
+                EmptySearch => $EmptySearch
+            },
         );
 
+        # output Dynamic fields blocks
+        # cycle trough the activated Dynamic Fields for this screen
+        DYNAMICFIELD:
+        for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+            next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+            # skip fields that HTML could not be retrieved
+            next DYNAMICFIELD if !IsHashRefWithData(
+                $DynamicFieldHTML{ $DynamicFieldConfig->{Name} }
+            );
+
+            $Self->{LayoutObject}->Block(
+                Name => 'DynamicField',
+                Data => {
+                    Label => $DynamicFieldHTML{ $DynamicFieldConfig->{Name} }->{Label},
+                    Field => $DynamicFieldHTML{ $DynamicFieldConfig->{Name} }->{Field},
+                },
+            );
+        }
+
         # comapt. map for attributes
         my %Map = (
             TimeSearchType        => 'TicketCreate',
