@@ -1,6 +1,8 @@
 # --
 # Kernel/Output/HTML/TicketOverviewMedium.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: TicketOverviewMedium.pm,v 1.54 2012-04-20 12:00:31 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,6 +19,9 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.54 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -239,30 +244,18 @@ sub _Show {
         Type     => 'move_into',
     );
 
-    # get last customer article
+    # get last article
     my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
         TicketID      => $Param{TicketID},
         DynamicFields => 0,
     );
 
-    # get ticket data
-    my %Ticket = $Self->{TicketObject}->TicketGet(
-       TicketID      => $Param{TicketID},
-       DynamicFields => 0,
-    );
-
-    # show ticket create time in current view
-    $Article{Created} = $Ticket{Created};
-
     # Fallback for tickets without articles: get at least basic ticket data
     if ( !%Article ) {
-        %Article = %Ticket;
-        if ( !$Article{Title} ) {
-            $Article{Title} = $Self->{LayoutObject}->{LanguageObject}->Get(
-                'This ticket has no title or subject'
-            );
-        }
-        $Article{Subject} = $Article{Title};
+        %Article = $Self->{TicketObject}->TicketGet(
+            TicketID      => $Param{TicketID},
+            DynamicFields => 0,
+        );
     }
 
     # user info
