@@ -1,6 +1,8 @@
 # --
 # Kernel/System/CheckItem.pm - the global spelling module
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: CheckItem.pm,v 1.41 2011-09-07 20:52:38 en Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,7 +14,8 @@ package Kernel::System::CheckItem;
 use strict;
 use warnings;
 
-use Email::Valid;
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.41 $) [1];
 
 =head1 NAME
 
@@ -133,7 +136,32 @@ sub CheckEmail {
     my $Error = '';
 
     # email address syntax check
-    if ( !Email::Valid->address( $Param{Address} ) ) {
+    if (
+        $Param{Address}
+        !~ m{
+            ^
+            [a-zA-Z0-9_#]+
+            (?:
+                [a-zA-Z0-9_+\.&%-/=]*
+                [a-zA-Z0-9_'\.-]+
+            )?
+            @
+            (?:
+                (?:
+                    [a-zA-Z0-9]+
+                    ([a-zA-Z0-9\.-]*[a-zA-Z0-9]+)?
+                    \.+
+                    [a-zA-Z]{2,8}
+                )
+                |
+                (?:
+                    \d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}
+                )
+            )
+            $
+        }x
+        )
+    {
         $Error = "Invalid syntax";
         $Self->{ErrorType} = 'InvalidSyntax';
     }
@@ -149,7 +177,7 @@ sub CheckEmail {
     # mx check
     elsif (
         $Self->{ConfigObject}->Get('CheckMXRecord')
-        && eval { require Net::DNS }    ## no critic
+        && eval { require Net::DNS }
         )
     {
 
@@ -170,8 +198,8 @@ sub CheckEmail {
             }
 
             # A recorde lookup
-            my $Packet = $Resolver->send( $Host, 'A' );
-            if ( !$Packet ) {
+            my $packet = $Resolver->send( $Host, 'A' );
+            if ( !$packet ) {
                 $Self->{ErrorType} = 'InvalidDNS';
                 $Error = "DNS problem: " . $Resolver->errorstring();
                 $Self->{LogObject}->Log(
@@ -179,16 +207,16 @@ sub CheckEmail {
                     Message  => "DNS problem: " . $Resolver->errorstring(),
                 );
             }
-            elsif ( $Packet->header()->ancount() ) {
+            elsif ( $packet->header->ancount() ) {
 
                 # OK
-                # print STDERR "OK A $Host ".$Packet->header->ancount()."\n";
+                # print STDERR "OK A $Host ".$packet->header->ancount()."\n";
             }
 
             # mx recorde lookup
             else {
-                my $Packet = $Resolver->send( $Host, 'MX' );
-                if ( !$Packet ) {
+                my $packet = $Resolver->send( $Host, 'MX' );
+                if ( !$packet ) {
                     $Self->{ErrorType} = 'InvalidDNS';
                     $Error = "DNS problem: " . $Resolver->errorstring();
                     $Self->{LogObject}->Log(
@@ -196,10 +224,10 @@ sub CheckEmail {
                         Message  => "DNS problem: " . $Resolver->errorstring(),
                     );
                 }
-                elsif ( $Packet->header()->ancount() ) {
+                elsif ( $packet->header->ancount() ) {
 
                     # OK
-                    # print STDERR "OK MX $Host ".$Packet->header->ancount()."\n";
+                    # print STDERR "OK MX $Host ".$packet->header->ancount()."\n";
                 }
                 else {
                     $Error = "no mail exchanger (mx) found!";
@@ -336,3 +364,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.41 $ $Date: 2011-09-07 20:52:38 $
+
+=cut
