@@ -1,8 +1,8 @@
 # --
 # Kernel/System/DynamicField/Backend.pm - Interface for DynamicField backends
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
-# $Id: Backend.pm,v 1.68 2012/03/01 11:34:05 mg Exp $
+# $Id: Backend.pm,v 1.71.2.1 2013-01-10 15:43:33 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,7 +18,7 @@ use Scalar::Util qw(weaken);
 use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.68 $) [1];
+$VERSION = qw($Revision: 1.71.2.1 $) [1];
 
 =head1 NAME
 
@@ -312,7 +312,7 @@ sub EditFieldRender {
         return;
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -392,7 +392,7 @@ sub DisplayValueRender {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -456,7 +456,7 @@ sub ValueSet {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -491,7 +491,7 @@ sub ValueSet {
         return;
     }
 
-    # set the dyanamic filed object handler
+    # set the dyanamic field object handler
     my $DynamicFieldObjectHandler =
         'DynamicField' . $Param{DynamicFieldConfig}->{ObjectType} . 'HandlerObject';
 
@@ -547,7 +547,7 @@ sub ValueDelete {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -561,6 +561,62 @@ sub ValueDelete {
     return $Self->{$DynamicFieldBackend}->ValueDelete(%Param);
 }
 
+=item AllValuesDelete()
+
+deletes all values of a dynamic field.
+
+    my $Success = $BackendObject->AllValuesDelete(
+        DynamicFieldConfig => $DynamicFieldConfig,      # complete config of the DynamicField
+        UserID             => 123,
+    );
+
+=cut
+
+sub AllValuesDelete {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for my $Needed (qw(DynamicFieldConfig UserID)) {
+        if ( !$Param{$Needed} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            return;
+        }
+    }
+
+    # check DynamicFieldConfig (general)
+    if ( !IsHashRefWithData( $Param{DynamicFieldConfig} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "The field configuration is invalid",
+        );
+        return;
+    }
+
+    # check DynamicFieldConfig (internally)
+    for my $Needed (qw(ID FieldType ObjectType)) {
+        if ( !$Param{DynamicFieldConfig}->{$Needed} ) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed in DynamicFieldConfig!"
+            );
+            return;
+        }
+    }
+
+    # set the dynamic field specific backend
+    my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
+
+    if ( !$Self->{$DynamicFieldBackend} ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Backend $Param{DynamicFieldConfig}->{FieldType} is invalid!"
+        );
+        return;
+    }
+
+    return $Self->{$DynamicFieldBackend}->AllValuesDelete(%Param);
+}
+
 =item ValueValidate()
 
 validates a dynamic field value.
@@ -901,7 +957,7 @@ sub EditFieldValueGet {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -981,7 +1037,7 @@ sub EditFieldValueValidate {
         return;
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1036,7 +1092,7 @@ sub IsSortable {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1061,6 +1117,10 @@ creates the field HTML to be used in search masks.
         DynamicFieldConfig   => $DynamicFieldConfig,      # complete config of the DynamicField
         ParamObject          => $ParamObject,
         Profile              => $ProfileData,             # search template data to load
+        PossibleValuesFilter => {                         # optional. Some backends may support this.
+            'Key1' => 'Value1',                           #     This may be needed to realize ACL support for ticket masks,
+            'Key2' => 'Value2',                           #     where the possible values can be limited with and ACL.
+        },
         DefaultValue         => $Value,                   # optional, depending on each field type e.g
                                                           #   $Value = a text';
                                                           #   $Value
@@ -1124,7 +1184,7 @@ sub SearchFieldRender {
         $Param{UseLabelHints} = 1;
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1265,7 +1325,7 @@ sub SearchFieldValueGet {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1300,8 +1360,8 @@ build the search parameters to be passed to the search engine.
                                                         #   Like              => 'value*',
                                                         #   GreaterThan       => '2001-01-01 01:01:01',
                                                         #   GreaterThanEquals => '2001-01-01 01:01:01',
-                                                        #   LowerThan         => '2002-02-02 02:02:02',
-                                                        #   LowerThanEquals   => '2002-02-02 02:02:02',
+                                                        #   SmallerThan         => '2002-02-02 02:02:02',
+                                                        #   SmallerThanEquals   => '2002-02-02 02:02:02',
         },
         Display => $DisplayValue,                       # the value to be displayed in the search terms section
     };
@@ -1338,7 +1398,7 @@ sub SearchFieldParameterBuild {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1405,7 +1465,7 @@ sub StatsFieldParameterBuild {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1439,8 +1499,8 @@ build the search parameters to be passed to the search engine within the stats m
                                                         #   Like              => 'value*',
                                                         #   GreaterThan       => '2001-01-01 01:01:01',
                                                         #   GreaterThanEquals => '2001-01-01 01:01:01',
-                                                        #   LowerThan         => '2002-02-02 02:02:02',
-                                                        #   LowerThanEquals   => '2002-02-02 02:02:02',
+                                                        #   SmallerThan         => '2002-02-02 02:02:02',
+                                                        #   SmallerThanEquals   => '2002-02-02 02:02:02',
         },
     };
 =cut
@@ -1476,7 +1536,7 @@ sub CommonSearchFieldParameterBuild {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1541,7 +1601,7 @@ sub ReadableValueRender {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1636,7 +1696,7 @@ sub TemplateValueTypeGet {
         $Param{FieldType} = 'All';
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1700,7 +1760,7 @@ sub IsAJAXUpdateable {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1767,7 +1827,7 @@ sub RandomValueSet {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1790,7 +1850,7 @@ sub RandomValueSet {
         return;
     }
 
-    # set the dyanamic filed object handler
+    # set the dyanamic field object handler
     my $DynamicFieldObjectHandler =
         'DynamicField' . $Param{DynamicFieldConfig}->{ObjectType} . 'HandlerObject';
 
@@ -1850,7 +1910,7 @@ sub IsMatchable {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1924,7 +1984,7 @@ sub ObjectMatch {
     # do not perfom the action if the ObjectAttributes parameter is empty
     return if !IsHashRefWithData( $Param{ObjectAttributes} );
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -1991,7 +2051,7 @@ sub AJAXPossibleValuesGet {
         }
     }
 
-    # set the dynamic filed specific backend
+    # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
     if ( !$Self->{$DynamicFieldBackend} ) {
@@ -2007,6 +2067,74 @@ sub AJAXPossibleValuesGet {
         %Param
     );
 }
+
+=item HistoricalValuesGet()
+
+returns the list of database values for a defined dynamic field. This function is used to calculate
+ACLs in Search Dialog
+
+    my $HistorialValues = $BackendObject->HistoricalValuesGet(
+        DynamicFieldConfig => $DynamicFieldConfig,       # complete config of the DynamicField
+    );
+
+    Returns:
+
+    $HistoricalValues = {
+        '1'     => '1',
+        'Item1' => 'Item1',
+        'Item2' => 'Item2',
+    }
+
+=cut
+
+sub HistoricalValuesGet {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    for my $Needed (qw(DynamicFieldConfig)) {
+        if ( !$Param{$Needed} ) {
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Needed!" );
+            return;
+        }
+    }
+
+    # check DynamicFieldConfig (general)
+    if ( !IsHashRefWithData( $Param{DynamicFieldConfig} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "The field configuration is invalid",
+        );
+        return;
+    }
+
+    # check DynamicFieldConfig (internally)
+    for my $Needed (qw(ID FieldType ObjectType)) {
+        if ( !$Param{DynamicFieldConfig}->{$Needed} ) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed in DynamicFieldConfig!"
+            );
+            return;
+        }
+    }
+
+    # set the dynamic field specific backend
+    my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
+
+    if ( !$Self->{$DynamicFieldBackend} ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Backend $Param{DynamicFieldConfig}->{FieldType} is invalid!"
+        );
+        return;
+    }
+
+    # call HistorialValuesGet on the specific backend
+    return $Self->{$DynamicFieldBackend}->HistoricalValuesGet(
+        %Param
+    );
+}
+
 1;
 
 =back
@@ -2023,6 +2151,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.68 $ $Date: 2012/03/01 11:34:05 $
+$Revision: 1.71.2.1 $ $Date: 2013-01-10 15:43:33 $
 
 =cut
