@@ -1,6 +1,8 @@
 # --
 # Kernel/System/DynamicField/Backend/Dropdown.pm - Delegate for DynamicField Dropdown backend
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# --
+# $Id: Dropdown.pm,v 1.63.2.1 2012-05-31 01:26:10 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,6 +18,9 @@ use Kernel::System::VariableCheck qw(:all);
 use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.63.2.1 $) [1];
+
 =head1 NAME
 
 Kernel::System::DynamicField::Backend::Dropdown
@@ -186,7 +191,7 @@ sub EditFieldRender {
     my $FieldName   = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
     my $FieldLabel  = $Param{DynamicFieldConfig}->{Label};
 
-    my $Value;
+    my $Value = '';
 
     # set the field value or default
     if ( $Param{UseDefaultValue} ) {
@@ -194,15 +199,6 @@ sub EditFieldRender {
     }
     $Value = $Param{Value} if defined $Param{Value};
 
-    # check if a value in a template (GenericAgent etc.)
-    # is configured for this dynamic field
-    if (
-        IsHashRefWithData( $Param{Template} )
-        && defined $Param{Template}->{ $FieldName }
-    ) {
-        $Value = $Param{Template}->{ $FieldName };
-    }
-
     # extract the dynamic field value form the web request
     my $FieldValue = $Self->EditFieldValueGet(
         %Param,
@@ -226,10 +222,10 @@ sub EditFieldRender {
     $FieldClass .= ' ServerError' if $Param{ServerError};
 
     # set PossibleValues
-    my $PossibleValues = $FieldConfig->{PossibleValues};
+    my $SelectionData = $FieldConfig->{PossibleValues};
 
     # use PossibleValuesFilter if defined
-    $PossibleValues = $Param{PossibleValuesFilter}
+    $SelectionData = $Param{PossibleValuesFilter}
         if defined $Param{PossibleValuesFilter};
 
     # set PossibleNone attribute
@@ -253,9 +249,9 @@ sub EditFieldRender {
     }
 
     my $HTMLString = $Param{LayoutObject}->BuildSelection(
-        Data         => $PossibleValues || {},
+        Data => $SelectionData || {},
+        Name => $FieldName,
         SelectedID   => $Value,
-        Name         => $FieldName,
         Translation  => $FieldConfig->{TranslatableValues} || 0,
         PossibleNone => $FieldPossibleNone,
         Class        => $FieldClass,
@@ -324,6 +320,25 @@ EOF
 EOF
     }
 
+    if ( $Param{SubmitOnChange} ) {
+
+        my $FieldSelector = '#' . $FieldName;
+
+        #add js to disable validation and do submit()
+        $HTMLString .= <<"EOF";
+<!--dtl:js_on_document_complete-->
+<script type="text/javascript">//<![CDATA[
+    \$('$FieldSelector').bind('change', function (Event) {
+        // make sure the ticket is not yet created on queue change
+        \$('input#Expand').val(1);
+        Core.Form.Validate.DisableValidation(\$(this).closest('form'));
+        \$(this).closest('form').submit();
+    });
+//]]></script>
+<!--dtl:js_on_document_complete-->
+EOF
+    }
+
     # call EditLabelRender on the common backend
     my $LabelString = $Self->{BackendCommonObject}->EditLabelRender(
         DynamicFieldConfig => $Param{DynamicFieldConfig},
@@ -521,7 +536,7 @@ sub SearchFieldRender {
 
     # add historic values to current values (if they don't exist anymore)
     if ( IsHashRefWithData($HistoricalValues) ) {
-        for my $Key ( sort keys %{$HistoricalValues} ) {
+        for my $Key ( keys %{$HistoricalValues} ) {
             if ( !$SelectionData->{$Key} ) {
                 $SelectionData->{$Key} = $HistoricalValues->{$Key}
             }
@@ -564,9 +579,8 @@ sub SearchFieldValueGet {
 
     # get dynamic field value form param object
     if ( defined $Param{ParamObject} ) {
-        my @FieldValues = $Param{ParamObject}->GetArray(
-            Param => 'Search_DynamicField_' . $Param{DynamicFieldConfig}->{Name}
-        );
+        my @FieldValues = $Param{ParamObject}
+            ->GetArray( Param => 'Search_DynamicField_' . $Param{DynamicFieldConfig}->{Name} );
 
         $Value = \@FieldValues;
     }
@@ -609,7 +623,7 @@ sub SearchFieldParameterBuild {
                 if ( $Param{DynamicFieldConfig}->{Config}->{TranslatableValues} ) {
 
                     # translate the value
-                    $DisplayItem = $Param{LayoutObject}->{LanguageObject}->Get($DisplayItem);
+                    $DisplayItem = $Param{LayoutObject}->{LanguageObject}->Get($DisplayValue);
                 }
 
                 push @DisplayItemList, $DisplayItem;
@@ -653,7 +667,7 @@ sub StatsFieldParameterBuild {
     );
 
     # add historic values to current values (if they don't exist anymore)
-    for my $Key ( sort keys %{$HistoricalValues} ) {
+    for my $Key ( keys %{$HistoricalValues} ) {
         if ( !$Values->{$Key} ) {
             $Values->{$Key} = $HistoricalValues->{$Key}
         }
@@ -772,9 +786,6 @@ sub ObjectMatch {
 
     my $FieldName = 'DynamicField_' . $Param{DynamicFieldConfig}->{Name};
 
-    # return false if field is not defined
-    return 0 if ( !defined $Param{ObjectAttributes}->{$FieldName} );
-
     # return false if not match
     if ( $Param{ObjectAttributes}->{$FieldName} ne $Param{Value} ) {
         return 0;
@@ -802,7 +813,7 @@ sub AJAXPossibleValuesGet {
         );
     }
 
-    # return the possible values hash as a reference
+    # retrun the possible values hash as a reference
     return \%PossibleValues;
 }
 
@@ -815,42 +826,10 @@ sub HistoricalValuesGet {
         ValueType => 'Text',
     );
 
-    # return the historical values from database
+    # retrun the historical values from database
     return $HistoricalValues;
 }
 
-sub ValueLookup {
-    my ( $Self, %Param ) = @_;
-
-    my $Value = defined $Param{Key} ? $Param{Key} : '';
-
-    # get real values
-    my $PossibleValues = $Param{DynamicFieldConfig}->{Config}->{PossibleValues};
-
-    if ($Value) {
-
-        # check if there is a real value for this key (otherwise keep the key)
-        if ( $Param{DynamicFieldConfig}->{Config}->{PossibleValues}->{$Value} ) {
-
-            # get readeable value
-            $Value = $Param{DynamicFieldConfig}->{Config}->{PossibleValues}->{$Value};
-
-            # check if translation is possible
-            if (
-                defined $Param{LanguageObject}
-                && $Param{DynamicFieldConfig}->{Config}->{TranslatableValues}
-                )
-            {
-
-                # translate value
-                $Value = $Param{LanguageObject}->Get($Value);
-            }
-        }
-    }
-
-    return $Value;
-}
-
 1;
 
 =back
@@ -864,3 +843,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$$
+
+=cut
