@@ -2,7 +2,7 @@
 # Kernel/System/DynamicField/Backend/TextArea.pm - Delegate for DynamicField TextArea backend
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: TextArea.pm,v 1.48.2.4 2012/05/07 21:43:10 cr Exp $
+# $Id: TextArea.pm,v 1.48.2.5 2012-11-14 22:14:54 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::DynamicFieldValue;
 use Kernel::System::DynamicField::Backend::BackendCommon;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.48.2.4 $) [1];
+$VERSION = qw($Revision: 1.48.2.5 $) [1];
 
 =head1 NAME
 
@@ -429,6 +429,11 @@ sub SearchFieldRender {
         $Value = $FieldValue;
     }
 
+    # check if value is an arrayref (GenericAgent Jobs and NotificationEvents)
+    if ( IsArrayRefWithData($Value) ) {
+        $Value = @{$Value}[0];
+    }
+
     # check and set class if necessary
     my $FieldClass = 'DynamicFieldText';
 
