@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket/Event/NotificationEvent.pm - a event module to send notifications
-# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: NotificationEvent.pm,v 1.23.2.3 2011/12/05 11:29:10 mg Exp $
+# $Id: NotificationEvent.pm,v 1.37.2.2 2012-12-10 15:07:40 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -16,9 +16,12 @@ use warnings;
 
 use Kernel::System::NotificationEvent;
 use Kernel::System::SystemAddress;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.23.2.3 $) [1];
+$VERSION = qw($Revision: 1.37.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -35,6 +38,20 @@ sub new {
         $Self->{$Needed} = $Param{$Needed} || die "Got no $Needed!";
     }
 
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
+
+    # get dynamic fields
+    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid      => 1,
+        ObjectType => ['Ticket'],
+    );
+
+    # create a dynamic field config lookup table
+    for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
+        $Self->{DynamicFieldConfigLookup}->{ $DynamicFieldConfig->{Name} } = $DynamicFieldConfig;
+    }
+
     return $Self;
 }
 
@@ -72,35 +89,14 @@ sub Run {
         UserID => $Param{UserID},
     );
 
-    # check if free text key X event got executed
-    if ( $Param{Event} eq 'TicketFreeTextUpdate' && $Param{Data} && $Param{Data}->{Counter} ) {
-        if ( !@IDs ) {
-            $Param{Event} = 'TicketFreeTextUpdate' . $Param{Data}->{Counter};
-            @IDs = $NotificationEventObject->NotificationEventCheck(
-                Event  => $Param{Event},
-                UserID => $Param{UserID},
-            );
-        }
-    }
-
-    # check if free time X event got executed
-    if ( $Param{Event} eq 'TicketFreeTimeUpdate' && $Param{Data} && $Param{Data}->{Counter} ) {
-        if ( !@IDs ) {
-            $Param{Event} = 'TicketFreeTimeUpdate' . $Param{Data}->{Counter};
-            @IDs = $NotificationEventObject->NotificationEventCheck(
-                Event  => $Param{Event},
-                UserID => $Param{UserID},
-            );
-        }
-    }
-
     # return if no notification for event exists
     return 1 if !@IDs;
 
     # get ticket attribute matches
     my %Ticket = $Self->{TicketObject}->TicketGet(
-        TicketID => $Param{Data}->{TicketID},
-        UserID   => $Param{UserID},
+        TicketID      => $Param{Data}->{TicketID},
+        UserID        => $Param{UserID},
+        DynamicFields => 1,
     );
 
     NOTIFICATION:
@@ -133,9 +129,33 @@ sub Run {
             VALUE:
             for my $Value ( @{ $Notification{Data}->{$Key} } ) {
                 next VALUE if !$Value;
-                if ( $Value eq $Ticket{$Key} ) {
-                    $Match = 1;
-                    last;
+
+                # check if key is a search dynamic field
+                if ( $Key =~ m{\A Search_DynamicField_}xms ) {
+
+                    # remove search prefix
+                    my $DynamicFieldName = $Key;
+
+                    $DynamicFieldName =~ s{Search_DynamicField_}{};
+
+                    # get the dynamic field config for this field
+                    my $DynamicFieldConfig = $Self->{DynamicFieldConfigLookup}->{$DynamicFieldName};
+
+                    next if !$DynamicFieldConfig;
+
+                    $Match = $Self->{BackendObject}->ObjectMatch(
+                        DynamicFieldConfig => $DynamicFieldConfig,
+                        Value              => $Value,
+                        ObjectAttributes   => \%Ticket,
+                    );
+                    last if $Match;
+                }
+                else {
+
+                    if ( $Value eq $Ticket{$Key} ) {
+                        $Match = 1;
+                        last;
+                    }
                 }
             }
             next NOTIFICATION if !$Match;
@@ -145,8 +165,9 @@ sub Run {
         my @Attachments;
         if ( $Param{Event} eq 'ArticleCreate' && $Param{Data}->{ArticleID} ) {
             my %Article = $Self->{TicketObject}->ArticleGet(
-                ArticleID => $Param{Data}->{ArticleID},
-                UserID    => $Param{UserID},
+                ArticleID     => $Param{Data}->{ArticleID},
+                UserID        => $Param{UserID},
+                DynamicFields => 0,
             );
 
             # check article type
@@ -228,7 +249,8 @@ sub _SendNotificationToRecipients {
 
     # get old article for quoting
     my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
-        TicketID => $Param{TicketID},
+        TicketID      => $Param{TicketID},
+        DynamicFields => 0,
     );
 
     # get recipients by Recipients
@@ -438,13 +460,31 @@ sub _SendNotificationToRecipients {
             }
         }
     }
+
+    # Get current user data
+    my %CurrentUser = $Self->{UserObject}->GetUserData(
+        UserID => $Param{UserID},
+    );
     $Self->{SystemAddressObject} = Kernel::System::SystemAddress->new( %{$Self} );
+    RECIPIENT:
     for my $Recipient (@Recipients) {
-        next
-            if (
+        if (
             $Self->{SystemAddressObject}
             ->SystemAddressIsLocalAddress( Address => $Recipient->{Email} )
-            );
+            )
+        {
+            next RECIPIENT;
+        }
+
+        # do not send email to self if AgentSelfNotification is set to No
+        if (
+            !$Self->{ConfigObject}->Get('AgentSelfNotifyOnAction')
+            && $Recipient->{Email} eq $CurrentUser{UserEmail}
+            )
+        {
+            next RECIPIENT
+        }
+
         $Self->_SendNotification(
             TicketID              => $Param{TicketID},
             UserID                => $Param{UserID},
@@ -470,7 +510,8 @@ sub _SendNotification {
 
     # get old article for quoting
     my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
-        TicketID => $Param{TicketID},
+        TicketID      => $Param{TicketID},
+        DynamicFields => 1,
     );
 
     # get notification texts
@@ -479,11 +520,6 @@ sub _SendNotification {
         $Notification{$_} = "No CustomerNotification $_ for $Param{Type} found!";
     }
 
-    # prepare customer realname
-    if ( $Notification{Body} =~ /<OTRS_CUSTOMER_REALNAME>/ && $Recipient{Realname} ) {
-        $Notification{Body} =~ s/<OTRS_CUSTOMER_REALNAME>/$Recipient{Realname}/g;
-    }
-
     # replace config options
     $Notification{Body}    =~ s{<OTRS_CONFIG_(.+?)>}{$Self->{ConfigObject}->Get($1)}egx;
     $Notification{Subject} =~ s{<OTRS_CONFIG_(.+?)>}{$Self->{ConfigObject}->Get($1)}egx;
@@ -497,11 +533,44 @@ sub _SendNotification {
     $Notification{Body} =~ s/<OTRS_TICKET_NUMBER>/$Article{TicketNumber}/gi;
 
     # ticket data
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Param{TicketID} );
-    for ( keys %Ticket ) {
-        next if !defined $Ticket{$_};
-        $Notification{Body}    =~ s/<OTRS_TICKET_$_>/$Ticket{$_}/gi;
-        $Notification{Subject} =~ s/<OTRS_TICKET_$_>/$Ticket{$_}/gi;
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Param{TicketID},
+        DynamicFields => 1,
+    );
+
+    # prepare customer realname
+    if ( $Notification{Body} =~ /<OTRS_CUSTOMER_REALNAME>/ ) {
+        my $RealName = $Self->{CustomerUserObject}->CustomerName(
+            UserLogin => $Ticket{CustomerUserID}
+        ) || $Recipient{Realname};
+        $Notification{Body} =~ s/<OTRS_CUSTOMER_REALNAME>/$RealName/g;
+    }
+
+    for my $Key ( keys %Ticket ) {
+        next if !defined $Ticket{$Key};
+
+        my $DisplayValue = $Ticket{$Key};
+
+        if ( $Key =~ /^DynamicField_/i ) {
+
+            my $FieldName = $Key;
+            $FieldName =~ s/DynamicField_//gi;
+
+            # get dynamic field config
+            my $DynamicField = $Self->{TicketObject}->{DynamicFieldObject}->DynamicFieldGet(
+                Name => $FieldName,
+            );
+
+            # get display value
+            my $ValueStrg = $Self->{TicketObject}->{DynamicFieldBackendObject}->ReadableValueRender(
+                DynamicFieldConfig => $DynamicField,
+                Value              => $DisplayValue,
+            );
+            $DisplayValue = $ValueStrg->{Value};
+        }
+
+        $Notification{Body}    =~ s/<OTRS_TICKET_$Key>/$DisplayValue/gi;
+        $Notification{Subject} =~ s/<OTRS_TICKET_$Key>/$DisplayValue/gi;
     }
 
     # cleanup
@@ -581,8 +650,9 @@ sub _SendNotification {
 
     # latest customer and agent article
     my @ArticleBoxAgent = $Self->{TicketObject}->ArticleGet(
-        TicketID => $Param{TicketID},
-        UserID   => $Param{UserID},
+        TicketID      => $Param{TicketID},
+        UserID        => $Param{UserID},
+        DynamicFields => 0,
     );
     my %ArticleAgent;
     for my $Article ( reverse @ArticleBoxAgent ) {
@@ -601,6 +671,9 @@ sub _SendNotification {
 
         if (%Article) {
             if ( $Article{Body} ) {
+
+                # Use the same line length as HTMLUtils::toAscii to avoid
+                #   line length problems.
                 $Article{Body} =~ s/(^>.+|.{4,78})(?:\s|\z)/$1\n/gm;
             }
             for ( keys %Article ) {
@@ -609,6 +682,15 @@ sub _SendNotification {
                 $Notification{Subject} =~ s/<$ArticleItem$_>/$Article{$_}/gi;
             }
 
+            # get accounted time
+            my $AccountedTime = $Self->{TicketObject}->ArticleAccountedTimeGet(
+                ArticleID => $Article{ArticleID},
+            );
+
+            my $MatchString = $ArticleItem . 'TimeUnit';
+            $Notification{Body}    =~ s/<$MatchString>/$AccountedTime/gi;
+            $Notification{Subject} =~ s/<$MatchString>/$AccountedTime/gi;
+
             # prepare subject (insert old subject)
             $Article{Subject} = $Self->{TicketObject}->TicketSubjectClean(
                 TicketNumber => $Article{TicketNumber},
