@@ -1,6 +1,8 @@
 # --
 # Kernel/System/VariableCheck.pm - helpers to check variables
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: VariableCheck.pm,v 1.6 2011-11-08 09:43:04 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,10 +14,11 @@ package Kernel::System::VariableCheck;
 use strict;
 use warnings;
 
-use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA $VERSION @EXPORT_OK %EXPORT_TAGS);
+$VERSION = qw($Revision: 1.6 $) [1];
 
 use Exporter;
-%EXPORT_TAGS = (    ## no critic
+%EXPORT_TAGS = (
     all => [
         'IsArrayRefWithData',
         'IsHashRefWithData',
@@ -48,7 +51,7 @@ input data validation, for example.
 Call this module directly without instantiating:
 
     use Kernel::System::VariableCheck qw(:all);             # export all functions into the calling package
-    use Kernel::System::VariableCheck qw(IsHashRefWitData); # export just one function
+    use Kernel::System::VariableCheck qw(IsHashRefWitData); # export just one funciton
 
     if (IsHashRefWithData($HashRef)) {
         ...
@@ -145,7 +148,7 @@ sub IsStringWithData {
 
 =item IsArrayRefWithData()
 
-test supplied data to determine if it is an array reference and contains at least one key
+test supplied data to deterine if it is an array reference and contains at least one key
 
 returns 1 if data matches criteria or undef otherwise
 
@@ -161,7 +164,7 @@ returns 1 if data matches criteria or undef otherwise
 sub IsArrayRefWithData {
     my $TestData = $_[0];
 
-    return if scalar @_ ne 1;
+    return if scalar @_     ne 1;
     return if ref $TestData ne 'ARRAY';
     return if !@{$TestData};
 
@@ -170,7 +173,7 @@ sub IsArrayRefWithData {
 
 =item IsHashRefWithData()
 
-test supplied data to determine if it is a hash reference and contains at least one key/value pair
+test supplied data to deterine if it is a hash reference and contains at least one key/value pair
 
 returns 1 if data matches criteria or undef otherwise
 
@@ -186,7 +189,7 @@ returns 1 if data matches criteria or undef otherwise
 sub IsHashRefWithData {
     my $TestData = $_[0];
 
-    return if scalar @_ ne 1;
+    return if scalar @_     ne 1;
     return if ref $TestData ne 'HASH';
     return if !%{$TestData};
 
@@ -284,7 +287,7 @@ sub IsIPv4Address {
 
         # allow numbers 0 to 255, no leading zeroes
         return if $Part !~ m{
-            \A (?: \d | [1-9] \d | [1] \d{2} | [2][0-4]\d | [2][5][0-5] ) \z
+            \A (?: \d | [1-9] \d | [1] \d\{2\} | [2][0-4]\d | [2][5][0-5] ) \z
         }xms;
     }
 
@@ -485,7 +488,7 @@ sub DataIsDifferent {
         my %B = %{ $Param{Data2} };
 
         # compare %A with %B and remove it if checked
-        for my $Key ( sort keys %A ) {
+        for my $Key ( keys %A ) {
 
             # Check if both are undefined
             if ( !defined $A{$Key} && !defined $B{$Key} ) {
@@ -539,3 +542,9 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
+
+=head1 VERSION
+
+$Revision: 1.6 $ $Date: 2011-11-08 09:43:04 $
+
+=cut
